@@ -15,13 +15,20 @@
 """
 
 import tempfile
+import logging
 import os
 from mkdocs.plugins import BasePlugin
 from mkdocs.theme import Theme
+from mkdocs.utils import warning_filter
 from mkdocs.contrib.search import SearchPlugin
 from mkdocs_monorepo_plugin.plugin import MonorepoPlugin
 from pymdownx.emoji import to_svg
 
+log = logging.getLogger(__name__)
+log.addFilter(warning_filter)
+
+TECHDOCS_DEFAULT_THEME = "material"
+
 
 class TechDocsCore(BasePlugin):
     def __init__(self):
@@ -35,20 +42,37 @@ class TechDocsCore(BasePlugin):
             "w+",
         ) as fp:
             fp.write(
-                '{\n  "site_name": "{{ config.site_name }}",\n  "site_description": "{{ config.site_description }}"\n}'
+                '{{ {"site_name": (config.site_name | string), '
+                '"site_description": (config.site_description | string)} | tojson }}'
             )
 
         mdx_configs_override = {}
         if "mdx_configs" in config:
             mdx_configs_override = config["mdx_configs"].copy()
 
+        # Pymdown snippets override to prevent legacy behavior impacting security https://github.com/facelessuser/pymdown-extensions/security/advisories/GHSA-jh85-wwv9-24hv
+        mdx_configs_override["pymdownx.snippets"] = {
+            "restrict_base_path": True,
+        }
+
         # Theme
-        config["theme"] = Theme(
-            name="material",
-            static_templates=[
-                "techdocs_metadata.json",
-            ],
-        )
+        if config["theme"].name != TECHDOCS_DEFAULT_THEME:
+            config["theme"] = Theme(name=TECHDOCS_DEFAULT_THEME)
+        elif config["theme"].name == TECHDOCS_DEFAULT_THEME:
+            log.info(
+                "[mkdocs-techdocs-core] Overridden '%s' theme settings in use",
+                TECHDOCS_DEFAULT_THEME,
+            )
+
+        if "features" not in config["theme"]:
+            config["theme"]["features"] = []
+
+        config["theme"]["features"].append("navigation.footer")
+        config["theme"]["features"].append("content.action.edit")
+
+        config["theme"]["palette"] = ""
+
+        config["theme"].static_templates.update({"techdocs_metadata.json"})
         config["theme"].dirs.append(self.tmp_dir_techdocs_theme.name)
 
         # Plugins
@@ -84,10 +108,12 @@ class TechDocsCore(BasePlugin):
         config["markdown_extensions"].append("pymdownx.magiclink")
         config["markdown_extensions"].append("pymdownx.mark")
         config["markdown_extensions"].append("pymdownx.smartsymbols")
+        config["markdown_extensions"].append("pymdownx.snippets")
         config["markdown_extensions"].append("pymdownx.superfences")
         config["markdown_extensions"].append("pymdownx.highlight")
         config["mdx_configs"]["pymdownx.highlight"] = {
             "linenums": True,
+            "pygments_lang_class": True,
         }
         config["markdown_extensions"].append("pymdownx.extra")
         config["mdx_configs"]["pymdownx.betterem"] = {
